import * as i0 from '@angular/core';
import { Injectable, NgModule } from '@angular/core';
import * as encoding from 'encoding-japanese';
import { AsyncSubject } from 'rxjs';

/**
 * Author: DaiDH
 * Library based on encoding-japanese
 * https://www.npmjs.com/package/ngx-shift-jis
 * https://www.npmjs.com/package/encoding-japanese
 */
class NgxShiftJisService {
    constructor() {
        this.types = [
            { reg: '\.(txt)$', type: 'text/plain;charset=utf-8' },
            { reg: '\.(csv)$', type: 'text/csv;charset=utf-8' },
            { reg: '\.(doc|dot)$', type: 'application/msword' },
            { reg: '\.(docx)$', type: 'application/vnd.openxmlformats-officedocument.wordprocessingml.document' },
            { reg: '\.(xls|xlt|xla)$', type: 'application/vnd.ms-excel' },
            { reg: '\.(xlsx)$', type: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' },
            { reg: '\.(xltx)$', type: 'application/vnd.openxmlformats-officedocument.spreadsheetml.template' },
            { reg: '\.(xlsm)$', type: 'application/vnd.ms-excel.sheet.macroEnabled.12' },
            { reg: '\.(xltm)$', type: 'application/vnd.ms-excel.template.macroEnabled.12' },
            { reg: '\.(xlam)$', type: 'application/vnd.ms-excel.addin.macroEnabled.12' },
            { reg: '\.(xlsb)$', type: 'application/vnd.ms-excel.sheet.binary.macroEnabled.12' },
            { reg: '\.(ppt|pot|pps|ppa)$', type: 'application/vnd.ms-powerpoint' },
            { reg: '\.(pptx)$', type: 'application/vnd.openxmlformats-officedocument.presentationml.presentation' },
            { reg: '\.(potx)$', type: 'application/vnd.openxmlformats-officedocument.presentationml.template' },
            { reg: '\.(ppsx)$', type: 'application/vnd.openxmlformats-officedocument.presentationml.slideshow' },
            { reg: '\.(ppam)$', type: 'application/vnd.ms-powerpoint.addin.macroEnabled.12' },
            { reg: '\.(pptm)$', type: 'application/vnd.ms-powerpoint.presentation.macroEnabled.12' },
            { reg: '\.(potm)$', type: 'application/vnd.ms-powerpoint.template.macroEnabled.12' },
            { reg: '\.(ppsm)$', type: 'application/vnd.ms-powerpoint.slideshow.macroEnabled.12' },
            { reg: '\.(mdb)$', type: 'application/vnd.ms-access' },
        ];
    }
    /**
     * encoding-japanese
     * @param content
     * @param fileName
     * @param convert
     */
    downloadShiftJIS(content = '', fileName = '', convert) {
        const as = new AsyncSubject();
        try {
            // encoding-japanese
            let num_array;
            let sjis_array;
            if (convert) {
                // custom
                sjis_array = convert(encoding);
            }
            else {
                // default SJIS UNICODE
                num_array = encoding.stringToCode(content);
                sjis_array = encoding.convert(num_array, "SJIS", "UNICODE");
            }
            const uint8_array = new Uint8Array(sjis_array);
            // Type
            const type = this.type(fileName);
            // Blob
            const blob = new Blob([uint8_array], { type: type && type.type });
            // Download
            this.downloadUri(blob, fileName, type, as);
            // AsyncSubject
        }
        catch (error) {
            as.error(error);
            as.complete();
        }
        return as;
    }
    /**
     * Type
     * @param fileName
     * @returns
     */
    type(fileName) {
        const type = this.types.find((f) => new RegExp(f.reg, 'i').test(fileName));
        return type || this.types[0];
    }
    /**
     * Download
     * @param blob
     * @param fileName
     * @param type
     * @param as
     */
    downloadUri(blob, fileName, type, as) {
        const url = window.URL.createObjectURL(blob);
        const a = document.createElement('a');
        a.href = url;
        a.download = fileName;
        a.click();
        a.remove();
        as.next({ url: url, blob: blob, fileName: fileName, fileType: type });
        as.complete();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.3", ngImport: i0, type: NgxShiftJisService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.3", ngImport: i0, type: NgxShiftJisService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.3", ngImport: i0, type: NgxShiftJisService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class NgxShiftJisModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.3", ngImport: i0, type: NgxShiftJisModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.3", ngImport: i0, type: NgxShiftJisModule }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.3", ngImport: i0, type: NgxShiftJisModule, providers: [NgxShiftJisService] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.3", ngImport: i0, type: NgxShiftJisModule, decorators: [{
            type: NgModule,
            args: [{
                    providers: [NgxShiftJisService]
                }]
        }] });

/*
 * Public API Surface of ngx-shift-jis
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxShiftJisModule, NgxShiftJisService };
//# sourceMappingURL=ngx-shift-jis.mjs.map
